Page MenuHomePhabricator

D16261.id39116.diff
No OneTemporary

D16261.id39116.diff

diff --git a/src/applications/repository/engine/PhabricatorRepositoryDiscoveryEngine.php b/src/applications/repository/engine/PhabricatorRepositoryDiscoveryEngine.php
--- a/src/applications/repository/engine/PhabricatorRepositoryDiscoveryEngine.php
+++ b/src/applications/repository/engine/PhabricatorRepositoryDiscoveryEngine.php
@@ -174,12 +174,13 @@
continue;
}
// In Git, it's possible to tag a tag. We just skip these, we'll discover
// them when we process the target tag. See T11180.
$fields = $ref->getRawFields();
+ $ref_type = idx($fields, 'objecttype');
$tag_type = idx($fields, '*objecttype');
- if ($tag_type == 'tag') {
- $this->log(pht('Skipping, this is a tag of a tag.'));
+ if ($ref_type != 'commit' && $tag_type != 'commit') {
+ $this->log(pht('Skipping, this is not a commit.'));
continue;
}
@@ -174,12 +174,13 @@
continue;
}
- // In Git, it's possible to tag a tag. We just skip these, we'll discover
- // them when we process the target tag. See T11180.
+ // In Git, it's possible to tag anything. We just skip tags that don't
+ // point to a commit. See T11301.
$fields = $ref->getRawFields();

File Metadata

Mime Type
text/plain
Expires
Fri, Oct 25, 11:31 AM (3 w, 4 d ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
6748556
Default Alt Text
D16261.id39116.diff (1 KB)

Event Timeline